************************************
The sherpa.plot.pylab_backend module
************************************

.. currentmodule:: sherpa.plot.pylab_backend

.. automodule:: sherpa.plot.pylab_backend

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      PylabBackend

Class Inheritance Diagram
=========================

.. inheritance-diagram::   PylabBackend
   :parts: 1